EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedRetentionRules_ResequenceRule',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Resequences a feed retention rule.'
GO

IF OBJECT_ID('[FeedRetentionRules_ResequenceRule]') IS NOT NULL DROP PROCEDURE [FeedRetentionRules_ResequenceRule]
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE PROCEDURE [FeedRetentionRules_ResequenceRule]
(
	@Feed_Id INT,
	@Sequence_Number INT,
	@New_Sequence_Number INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Rules TABLE
	(
		[Sequence_Number] INT NOT NULL,
		[DeletePrereleaseVersions_Indicator] CHAR(1) NOT NULL,
		[DeleteCached_Indicator] CHAR(1) NOT NULL,
		[KeepVersions_Count] INT NULL,
		[KeepUsedWithin_Days] INT NULL,
		[DeletePackageIds_Csv] NVARCHAR(MAX) NULL,
		[KeepPackageIds_Csv] NVARCHAR(MAX) NULL,
		[DeleteVersions_Csv] NVARCHAR(MAX) NULL,
		[KeepVersions_Csv] NVARCHAR(MAX) NULL,
		[SizeTrigger_KBytes] BIGINT NULL,
		[SizeExclusive_Indicator] CHAR(1) NOT NULL,
		[TriggerDownload_Count] INT NULL,
		[KeepConsumedWithin_Days] INT NULL,
		[KeepIfActivelyConsumed_Indicator] CHAR(1) NULL,
		[KeepPackageUsageRemoved_Days] INT NULL
	)

	INSERT INTO @Rules
	SELECT [Sequence_Number] = ROW_NUMBER() OVER (PARTITION BY [Feed_Id] ORDER BY [Sequence_Number]),
	       [DeletePrereleaseVersions_Indicator],
	       [DeleteCached_Indicator],
	       [KeepVersions_Count],
	       [KeepUsedWithin_Days],
	       [DeletePackageIds_Csv],
	       [KeepPackageIds_Csv],
	       [DeleteVersions_Csv],
	       [KeepVersions_Csv],
	       [SizeTrigger_KBytes],
	       [SizeExclusive_Indicator],
	       [TriggerDownload_Count],
		   [KeepConsumedWithin_Days],
		   [KeepIfActivelyConsumed_Indicator],
		   [KeepPackageUsageRemoved_Days]
	  FROM [FeedRetentionRules]
	  WITH (TABLOCKX)
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Sequence_Number] < @New_Sequence_Number
	   AND [Sequence_Number] <> @Sequence_Number

	DECLARE @Actual_New_Sequence_Number INT
	SET @Actual_New_Sequence_Number = (SELECT COUNT(*) FROM @Rules) + 1

	INSERT INTO @Rules
	SELECT [Sequence_Number] = @Actual_New_Sequence_Number,
	       [DeletePrereleaseVersions_Indicator],
	       [DeleteCached_Indicator],
	       [KeepVersions_Count],
	       [KeepUsedWithin_Days],
	       [DeletePackageIds_Csv],
	       [KeepPackageIds_Csv],
	       [DeleteVersions_Csv],
	       [KeepVersions_Csv],
	       [SizeTrigger_KBytes],
	       [SizeExclusive_Indicator],
	       [TriggerDownload_Count],
		   [KeepConsumedWithin_Days],
		   [KeepIfActivelyConsumed_Indicator],
		   [KeepPackageUsageRemoved_Days]
	  FROM [FeedRetentionRules]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Sequence_Number] = @Sequence_Number

	INSERT INTO @Rules
	SELECT [Sequence_Number] = ROW_NUMBER() OVER (PARTITION BY [Feed_Id] ORDER BY [Sequence_Number]) + @Actual_New_Sequence_Number,
	       [DeletePrereleaseVersions_Indicator],
	       [DeleteCached_Indicator],
	       [KeepVersions_Count],
	       [KeepUsedWithin_Days],
	       [DeletePackageIds_Csv],
	       [KeepPackageIds_Csv],
	       [DeleteVersions_Csv],
	       [KeepVersions_Csv],
	       [SizeTrigger_KBytes],
	       [SizeExclusive_Indicator],
	       [TriggerDownload_Count],
		   [KeepConsumedWithin_Days],
		   [KeepIfActivelyConsumed_Indicator],
		   [KeepPackageUsageRemoved_Days]
	  FROM [FeedRetentionRules]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Sequence_Number] >= @New_Sequence_Number
	   AND [Sequence_Number] <> @Sequence_Number

	DELETE [FeedRetentionRules]
	 WHERE [Feed_Id] = @Feed_Id

	INSERT INTO [FeedRetentionRules]
	SELECT [Feed_Id] = @Feed_Id,
	       [Sequence_Number],
	       [DeletePrereleaseVersions_Indicator],
		   [DeleteCached_Indicator],
		   [KeepVersions_Count],
		   [KeepUsedWithin_Days],
		   [DeletePackageIds_Csv],
		   [KeepPackageIds_Csv],
		   [DeleteVersions_Csv],
		   [KeepVersions_Csv],
		   [SizeTrigger_KBytes],
		   [SizeExclusive_Indicator],
		   [TriggerDownload_Count],
		   [KeepConsumedWithin_Days],
		   [KeepIfActivelyConsumed_Indicator],
		   [KeepPackageUsageRemoved_Days]
	  FROM @Rules

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO



GRANT EXECUTE ON [FeedRetentionRules_ResequenceRule] TO [ProGetUser_Role]
GO
	   

